@@ -27,14 +27,18 @@
 
 namespace kt
 {
-DBusSettings::DBusSettings(CoreInterface* core, QObject* parent) : QObject(parent), core(core)
+DBusSettings::DBusSettings(CoreInterface *core, QObject *parent)
+    : QObject(parent)
+    , core(core)
 {
-    QDBusConnection::sessionBus().registerObject(QStringLiteral("/settings"), this,
-            QDBusConnection::ExportScriptableSlots | QDBusConnection::ExportScriptableSignals);
+    QDBusConnection::sessionBus().registerObject(QStringLiteral("/settings"),
+                                                 this,
+                                                 QDBusConnection::ExportScriptableSlots | QDBusConnection::ExportScriptableSignals);
 }
 
 DBusSettings::~DBusSettings()
-{}
+{
+}
 
 void DBusSettings::apply()
 {
@@ -191,6 +195,16 @@ void DBusSettings::setUploadBandwidth(int val)
     Settings::setUploadBandwidth(val);
 }
 
+bool DBusSettings::alwaysMinimizeToSystemTray()
+{
+    return Settings::alwaysMinimizeToSystemTray();
+}
+
+void DBusSettings::setAlwaysMinimizeToSystemTray(bool val)
+{
+    Settings::setAlwaysMinimizeToSystemTray(val);
+}
+
 bool DBusSettings::showPopups()
 {
     return Settings::showPopups();
