@@ -21,8 +21,8 @@
 #ifndef __DBusSettings__
 #define __DBusSettings__
 
-#include <QObject>
 #include <QList>
+#include <QObject>
 #include <ktcore_export.h>
 
 namespace kt
@@ -34,7 +34,7 @@ class KTCORE_EXPORT DBusSettings : public QObject
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.ktorrent.settings")
 public:
-    DBusSettings(CoreInterface* core, QObject* parent);
+    DBusSettings(CoreInterface *core, QObject *parent);
     ~DBusSettings() override;
 
 public Q_SLOTS:
@@ -68,6 +68,8 @@ public Q_SLOTS:
     Q_SCRIPTABLE void setDownloadBandwidth(int val);
     Q_SCRIPTABLE int uploadBandwidth();
     Q_SCRIPTABLE void setUploadBandwidth(int val);
+    Q_SCRIPTABLE bool alwaysMinimizeToSystemTray();
+    Q_SCRIPTABLE void setAlwaysMinimizeToSystemTray(bool val);
     Q_SCRIPTABLE bool showPopups();
     Q_SCRIPTABLE void setShowPopups(bool val);
     Q_SCRIPTABLE bool keepSeeding();
@@ -190,8 +192,9 @@ public Q_SLOTS:
     Q_SCRIPTABLE void setShowTotalSpeedInTitle(bool val);
 
     Q_SCRIPTABLE void apply();
+
 private:
-    CoreInterface* core;
+    CoreInterface *core;
 };
 }
 
