@@ -25,17 +25,16 @@
 #include <KLocalizedString>
 #include <Syndication/Enclosure>
 
-#include <util/log.h>
-#include <util/file.h>
-#include <util/fileops.h>
-#include <bcodec/bnode.h>
-#include <bcodec/bencoder.h>
-#include <bcodec/bdecoder.h>
-#include "ktfeed.h"
+#include "feedretriever.h"
 #include "filter.h"
 #include "filterlist.h"
-#include "feedretriever.h"
-
+#include "ktfeed.h"
+#include <bcodec/bdecoder.h>
+#include <bcodec/bencoder.h>
+#include <bcodec/bnode.h>
+#include <util/file.h>
+#include <util/fileops.h>
+#include <util/log.h>
 
 using namespace bt;
 
@@ -43,14 +42,18 @@ namespace kt
 {
 const int DEFAULT_REFRESH_RATE = 60;
 
-
-Feed::Feed(const QString& dir) : dir(dir), status(UNLOADED), refresh_rate(DEFAULT_REFRESH_RATE)
+Feed::Feed(const QString &dir)
+    : dir(dir)
+    , status(UNLOADED)
+    , refresh_rate(DEFAULT_REFRESH_RATE)
 {
     connect(&update_timer, &QTimer::timeout, this, &Feed::refresh);
 }
 
-Feed::Feed(const QString& feed_url, const QString& dir)
-    : dir(dir), status(UNLOADED), refresh_rate(DEFAULT_REFRESH_RATE)
+Feed::Feed(const QString &feed_url, const QString &dir)
+    : dir(dir)
+    , status(UNLOADED)
+    , refresh_rate(DEFAULT_REFRESH_RATE)
 {
     parseUrl(feed_url);
     connect(&update_timer, &QTimer::timeout, this, &Feed::refresh);
@@ -58,8 +61,11 @@ Feed::Feed(const QString& feed_url, const QString& dir)
     save();
 }
 
-Feed::Feed(const QString& feed_url, Syndication::FeedPtr feed, const QString& dir)
-    : feed(feed), dir(dir), status(OK), refresh_rate(DEFAULT_REFRESH_RATE)
+Feed::Feed(const QString &feed_url, Syndication::FeedPtr feed, const QString &dir)
+    : feed(feed)
+    , dir(dir)
+    , status(OK)
+    , refresh_rate(DEFAULT_REFRESH_RATE)
 {
     parseUrl(feed_url);
     connect(&update_timer, &QTimer::timeout, this, &Feed::refresh);
@@ -70,7 +76,7 @@ Feed::~Feed()
 {
 }
 
-void Feed::parseUrl(const QString& feed_url)
+void Feed::parseUrl(const QString &feed_url)
 {
     QStringList sl = feed_url.split(QStringLiteral(":COOKIE:"));
     if (sl.size() == 2) {
@@ -80,7 +86,6 @@ void Feed::parseUrl(const QString& feed_url)
         url = QUrl(feed_url);
 }
 
-
 void Feed::save()
 {
     QString file = dir + QStringLiteral("info");
@@ -100,23 +105,23 @@ void Feed::save()
     }
     enc.write(QByteArrayLiteral("filters"));
     enc.beginList();
-    for (Filter* f : qAsConst(filters))
+    for (Filter *f : qAsConst(filters))
         enc.write(f->filterID().toUtf8());
     enc.end();
     enc.write(QByteArrayLiteral("loaded"));
     enc.beginList();
-    for (const QString& id : qAsConst(loaded))
+    for (const QString &id : qAsConst(loaded))
         enc.write(id.toUtf8());
     enc.end();
     enc.write(QByteArrayLiteral("downloaded_se_items"));
     enc.beginList();
-    QMap<Filter*, QList<SeasonEpisodeItem> >::iterator i = downloaded_se_items.begin();
+    QMap<Filter *, QList<SeasonEpisodeItem>>::iterator i = downloaded_se_items.begin();
     while (i != downloaded_se_items.end()) {
-        Filter* f = i.key();
-        const QList<SeasonEpisodeItem> & se = i.value();
+        Filter *f = i.key();
+        const QList<SeasonEpisodeItem> &se = i.value();
         enc.write(f->filterID().toUtf8());
         enc.beginList();
-        for (const SeasonEpisodeItem& item : se) {
+        for (const SeasonEpisodeItem &item : se) {
             enc.write((bt::Uint32)item.season);
             enc.write((bt::Uint32)item.episode);
         }
@@ -130,7 +135,7 @@ void Feed::save()
     enc.end();
 }
 
-void Feed::load(FilterList* filter_list)
+void Feed::load(FilterList *filter_list)
 {
     QString file = dir + QStringLiteral("info");
     QFile fptr(file);
@@ -141,13 +146,13 @@ void Feed::load(FilterList* filter_list)
 
     QByteArray data = fptr.readAll();
     BDecoder dec(data, false);
-    BNode* n = dec.decode();
+    BNode *n = dec.decode();
     if (!n || n->getType() != BNode::DICT) {
         delete n;
         return;
     }
 
-    BDictNode* dict = (BDictNode*)n;
+    BDictNode *dict = (BDictNode *)n;
 
     try {
         url = QUrl(dict->getString("url", 0));
@@ -155,34 +160,34 @@ void Feed::load(FilterList* filter_list)
         custom_name = dict->getValue("custom_name") ? dict->getString("custom_name", 0) : QString();
         refresh_rate = dict->getValue("refresh_rate") ? dict->getInt("refresh_rate") : DEFAULT_REFRESH_RATE;
 
-        BListNode* fl = dict->getList("filters");
+        BListNode *fl = dict->getList("filters");
         if (fl) {
             for (Uint32 i = 0; i < fl->getNumChildren(); i++) {
-                Filter* f = filter_list->filterByID(fl->getString(i, 0));
+                Filter *f = filter_list->filterByID(fl->getString(i, 0));
                 if (f)
                     filters.append(f);
             }
         }
 
-        BListNode* ll = dict->getList("loaded");
+        BListNode *ll = dict->getList("loaded");
         if (ll) {
             for (Uint32 i = 0; i < ll->getNumChildren(); i++) {
                 loaded.insert(ll->getString(i, 0));
             }
         }
 
-        BListNode* se_list = dict->getList("downloaded_se_items");
+        BListNode *se_list = dict->getList("downloaded_se_items");
         if (se_list) {
             for (Uint32 i = 0; i < se_list->getNumChildren(); i += 2) {
-                BListNode* se = se_list->getList(i + 1);
+                BListNode *se = se_list->getList(i + 1);
                 if (!se)
                     continue;
 
-                Filter* f = filter_list->filterByID(se_list->getString(i, 0));
+                Filter *f = filter_list->filterByID(se_list->getString(i, 0));
                 if (!f)
                     continue;
 
-                QList<SeasonEpisodeItem> & sel = downloaded_se_items[f];
+                QList<SeasonEpisodeItem> &sel = downloaded_se_items[f];
                 for (Uint32 j = 0; j < se->getNumChildren(); j += 2) {
                     SeasonEpisodeItem item;
                     item.episode = se->getInt(j);
@@ -206,7 +211,7 @@ void Feed::load(FilterList* filter_list)
         refresh();
 }
 
-void Feed::loadingComplete(Syndication::Loader* loader, Syndication::FeedPtr feed, Syndication::ErrorCode status)
+void Feed::loadingComplete(Syndication::Loader *loader, Syndication::FeedPtr feed, Syndication::ErrorCode status)
 {
     Q_UNUSED(loader);
     if (status != Syndication::Success) {
@@ -220,13 +225,13 @@ void Feed::loadingComplete(Syndication::Loader* loader, Syndication::FeedPtr fee
 
     Out(SYS_SYN | LOG_NOTICE) << "Loaded feed " << url.toDisplayString() << endl;
     this->feed = feed;
-    update_timer.start(refresh_rate * 60  * 1000);
+    update_timer.start(refresh_rate * 60 * 1000);
     this->status = OK;
 
     // refresh cache of feed_items_ids
     feed_items_id.clear();
     const QList<Syndication::ItemPtr> feedItems = feed->items();
-    for (const Syndication::ItemPtr& item : feedItems)
+    for (const Syndication::ItemPtr &item : feedItems)
         feed_items_id.insert(item->id());
 
     checkLoaded();
@@ -239,15 +244,15 @@ void Feed::refresh()
     status = DOWNLOADING;
     update_error.clear();
     update_timer.stop();
-    Syndication::Loader* loader = Syndication::Loader::create(this, SLOT(loadingComplete(Syndication::Loader*, Syndication::FeedPtr, Syndication::ErrorCode)));
-    FeedRetriever* retr = new FeedRetriever(dir + QStringLiteral("feed.xml"));
+    Syndication::Loader *loader = Syndication::Loader::create(this, SLOT(loadingComplete(Syndication::Loader *, Syndication::FeedPtr, Syndication::ErrorCode)));
+    FeedRetriever *retr = new FeedRetriever(dir + QStringLiteral("feed.xml"));
     if (!cookie.isEmpty())
         retr->setAuthenticationCookie(cookie);
     loader->loadFrom(url, retr);
     updated();
 }
 
-void Feed::loadingFromDiskComplete(Syndication::Loader* loader, Syndication::FeedPtr feed, Syndication::ErrorCode status)
+void Feed::loadingFromDiskComplete(Syndication::Loader *loader, Syndication::FeedPtr feed, Syndication::ErrorCode status)
 {
     loadingComplete(loader, feed, status);
     refresh();
@@ -257,7 +262,8 @@ void Feed::loadFromDisk()
 {
     status = DOWNLOADING;
     update_timer.stop();
-    Syndication::Loader* loader = Syndication::Loader::create(this, SLOT(loadingFromDiskComplete(Syndication::Loader*, Syndication::FeedPtr, Syndication::ErrorCode)));
+    Syndication::Loader *loader =
+        Syndication::Loader::create(this, SLOT(loadingFromDiskComplete(Syndication::Loader *, Syndication::FeedPtr, Syndication::ErrorCode)));
     loader->loadFrom(QUrl(dir + QStringLiteral("feed.xml")), new FeedRetriever());
     updated();
 }
@@ -270,7 +276,7 @@ QString Feed::title() const
         return url.toDisplayString();
 }
 
-QString Feed::newFeedDir(const QString& base)
+QString Feed::newFeedDir(const QString &base)
 {
     int cnt = 0;
     QString dir = QStringLiteral("%1feed%2/").arg(base).arg(cnt);
@@ -283,20 +289,20 @@ QString Feed::newFeedDir(const QString& base)
     return dir;
 }
 
-void Feed::addFilter(Filter* f)
+void Feed::addFilter(Filter *f)
 {
     filters.append(f);
     updated();
 }
 
-void Feed::removeFilter(Filter* f)
+void Feed::removeFilter(Filter *f)
 {
     filters.removeAll(f);
     downloaded_se_items.remove(f);
     updated();
 }
 
-bool Feed::needToDownload(Syndication::ItemPtr item, Filter* filter)
+bool Feed::needToDownload(Syndication::ItemPtr item, Filter *filter)
 {
     bool m = filter->match(item);
     if ((m && filter->downloadMatching()) || (!m && filter->downloadNonMatching())) {
@@ -308,7 +314,7 @@ bool Feed::needToDownload(Syndication::ItemPtr item, Filter* filter)
                 downloaded_se_items[filter].append(SeasonEpisodeItem(s, e));
             } else {
                 // If we have already downloaded this season and episode, return
-                QList<SeasonEpisodeItem> & ses = downloaded_se_items[filter];
+                QList<SeasonEpisodeItem> &ses = downloaded_se_items[filter];
                 SeasonEpisodeItem se(s, e);
                 if (ses.contains(se))
                     return false;
@@ -329,10 +335,10 @@ void Feed::runFilters()
         return;
 
     Out(SYS_SYN | LOG_NOTICE) << "Running filters on " << feed->title() << endl;
-    for (Filter* f : qAsConst(filters)) {
+    for (Filter *f : qAsConst(filters)) {
         f->startMatching();
         const QList<Syndication::ItemPtr> items = feed->items();
-        for (const Syndication::ItemPtr& item : items) {
+        for (const Syndication::ItemPtr &item : items) {
             // Skip already loaded items
             if (loaded.contains(item->id()))
                 continue;
@@ -347,7 +353,7 @@ void Feed::runFilters()
 
 QString TorrentUrlFromItem(Syndication::ItemPtr item);
 
-void Feed::downloadItem(Syndication::ItemPtr item, const QString& group, const QString& location, const QString& move_on_completion, bool silently)
+void Feed::downloadItem(Syndication::ItemPtr item, const QString &group, const QString &location, const QString &move_on_completion, bool silently)
 {
     loaded.insert(item->id());
     QString url = TorrentUrlFromItem(item);
@@ -390,7 +396,6 @@ bool Feed::downloaded(Syndication::ItemPtr item) const
     return loaded.contains(item->id());
 }
 
-
 QString Feed::displayName() const
 {
     if (!custom_name.isEmpty())
@@ -401,8 +406,7 @@ QString Feed::displayName() const
         return url.toDisplayString();
 }
 
-
-void Feed::setDisplayName(const QString& dname)
+void Feed::setDisplayName(const QString &dname)
 {
     if (custom_name != dname) {
         custom_name = dname;
@@ -411,7 +415,6 @@ void Feed::setDisplayName(const QString& dname)
     }
 }
 
-
 void Feed::setRefreshRate(bt::Uint32 r)
 {
     if (r > 0) {
@@ -421,23 +424,31 @@ void Feed::setRefreshRate(bt::Uint32 r)
     }
 }
 
-
 //////////////////////////////////
-SeasonEpisodeItem::SeasonEpisodeItem() : season(-1), episode(-1)
-{}
+SeasonEpisodeItem::SeasonEpisodeItem()
+    : season(-1)
+    , episode(-1)
+{
+}
 
-SeasonEpisodeItem::SeasonEpisodeItem(int s, int e) : season(s), episode(e)
-{}
+SeasonEpisodeItem::SeasonEpisodeItem(int s, int e)
+    : season(s)
+    , episode(e)
+{
+}
 
-SeasonEpisodeItem::SeasonEpisodeItem(const SeasonEpisodeItem& item) : season(item.season), episode(item.episode)
-{}
+SeasonEpisodeItem::SeasonEpisodeItem(const SeasonEpisodeItem &item)
+    : season(item.season)
+    , episode(item.episode)
+{
+}
 
-bool SeasonEpisodeItem::operator == (const SeasonEpisodeItem& item) const
+bool SeasonEpisodeItem::operator==(const SeasonEpisodeItem &item) const
 {
     return season == item.season && episode == item.episode;
 }
 
-SeasonEpisodeItem& SeasonEpisodeItem::operator = (const SeasonEpisodeItem& item)
+SeasonEpisodeItem &SeasonEpisodeItem::operator=(const SeasonEpisodeItem &item)
 {
     season = item.season;
     episode = item.episode;
@@ -474,7 +485,7 @@ QString Feed::filterNamesString() const
     if (filters.empty())
         return i18n("None");
     QStringList names;
-    for (Filter* f : qAsConst(filters))
+    for (Filter *f : qAsConst(filters))
         names << f->filterName();
     return names.join(QStringLiteral(", "));
 }
